meta = {'title': 'I Read Solidity Ireadsolidity Com Readsolidity Irs', 'description_html': 'I Read Solidity Ireadsolidity Com Readsolidity Irs. read, solidity, ireadsolidity, com, readsolidity, irs… | ireadsolidity.com | IRS ', 'description': 'I Read Solidity Ireadsolidity Com Readsolidity Irs. read, solidity, ireadsolidity, com, readsolidity, irs… | ireadsolidity.com | IRS ', 'keywords': 'read, solidity, ireadsolidity, com, readsolidity, irs | ireadsolidity.com | IRS ', 'thumbnail': '', 'thumbnail_link': '', 'thumbnail_resized': None, 'thumbnail_url_resized': None, 'canonical': 'ireadsolidity.com', 'mobile_url': 'ireadsolidity.com', 'oembed_url': 'ireadsolidity.com/oembed?url=ireadsolidity.com', 'og': {'type': 'article.other', 'title': 'I Read Solidity Ireadsolidity Com Readsolidity Irs | ireadsolidity.com', 'description': 'I Read Solidity Ireadsolidity Com Readsolidity Irs. read, solidity, ireadsolidity, com, readsolidity, irs… | ireadsolidity.com | IRS ', 'url': 'ireadsolidity.com', 'image': '', 'image_alt': 'I Read Solidity Ireadsolidity Com Readsolidity Irs | ireadsolidity.com | IRS ', 'image_width': '1200', 'image_height': '627', 'image_type': 'image/jpeg', 'locale': 'en_US', 'fb_app_id': '427305388009806', 'site_name': 'i read solidity', 'updated_time': '2025-11-24T00:59:23.394Z', 'article': {'published_time': '2025-11-24T00:59:23.394Z', 'modified_time': '2025-11-24T00:59:23.394Z', 'section': 'Health', 'tag': ['read', ' solidity', ' ireadsolidity', ' com', ' readsolidity', ' irs']}}, 'twitter': {'card': 'summary_large_image', 'title': 'I Read Solidity Ireadsolidity Com Readsolidity Irs | ireadsolidity.com', 'description': 'I Read Solidity Ireadsolidity Com Readsolidity Irs. read, solidity, ireadsolidity, com, readsolidity, irs… | ireadsolidity.com | IRS ', 'site': '@ireadsolidity', 'site:id': '123456789', 'creator': '@ireadsolidity', 'creator:id': '123456789', 'image': '', 'image_alt': 'I Read Solidity Ireadsolidity Com Readsolidity Irs | ireadsolidity.com | IRS ', 'image_type': 'image/jpeg', 'domain': 'ireadsolidity.com'}, 'other': {'robots': 'index, follow', 'googlebot': 'index, follow', 'bingbot': 'noarchive', 'yahooContent': 'article', 'msvalidate.01': '', 'yandex-verification': '', 'author': '@ireadsolidity', 'revisit-after': '7 days', 'rating': 'General', 'application-name': 'i read solidity', 'distribution': 'global', 'content_type': 'text/html; charset=utf-8', 'charset': 'UTF-8', 'viewport': 'width=device-width, initial-scale=1, maximum-scale=2, shrink-to-fit=no', 'referrer': 'origin-when-crossorigin', 'color_scheme': 'light', 'theme_color': '#FFFFFF', 'manifest': '/data/manifest/'}}
input(meta)
